
Eve-Elastic is written and maintained by:

* Petr Jasek
* Andrew Mleczko
* Mugur Rus
* Adrian Magdas
* Tolga Akin
* Jonathan Dray
* Siva Kuna
* Tolga Akin
* Nicholas Iaquinto
* Anca Farcas
* Dinu Gherman
* Mayur Dhamanwala

